==> pysolorie-1.3.0.tar.gz: pysolorie-1.3.0/README.md <==
# pysolorie

[![Quality Checks](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml)
[![Publish](https://github.com/aaghamohammadi/pysolorie/actions/workflows/publish.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions/workflows/publish.yml)
![GitHub License](https://img.shields.io/github/license/aaghamohammadi/pysolorie)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pysolorie)
[![Documentation Status](https://readthedocs.org/projects/pysolorie/badge/?version=latest)](https://pysolorie.readthedocs.io/en/latest/?badge=latest)
![PyPI - Version](https://img.shields.io/pypi/v/pysolorie)
![PyPI - Format](https://img.shields.io/pypi/format/pysolorie)
![PyPI - Status](https://img.shields.io/pypi/status/pysolorie)
[![codecov](https://codecov.io/gh/aaghamohammadi/pysolorie/graph/badge.svg?token=TF9E8Y3Q67)](https://codecov.io/gh/aaghamohammadi/pysolorie)

**pysolorie** stands for **Py**thon **So**lar **Orie**ntation Analysis of Solar Panel. It is a Python library designed to help you analyze the orientation of solar panels.

How can one find the optimal orientation of a solar panel to maximize the total energy received from the sun?

## Features

``pysolorie`` is a library designed to help you find this optimal orientation. Its features include, but are not limited to:

- Finding the optimal orientation for a fixed solar panel under the assumption of a clear-sky model.
- Plotting the Optimal Orientation for a range of days.
- Generating a CSV Report of the optimal orientation for a range of days.
- Calculating the sunrise and sunset hour angles for a given day.
- Utilizing the Hottel Model to estimate clear-sky beam radiation transmittance.
- Calculating the zenith angle.
- Calculating the solar time.
- Calculating Solar Declination and Hour Angle.



## Documentation

You can find the complete documentation for pysolorie at our [Read the Docs page](https://pysolorie.readthedocs.io/).

## Contributing

We welcome contributions to pysolorie! If you're interested in contributing, please take a look at our [contribution guidelines](https://pysolorie.readthedocs.io/en/latest/contributing.html) for detailed information on how you can help.

Thank you for considering contributing to pysolorie!

==> pysolorie-1.4.0.tar.gz: pysolorie-1.4.0/README.md <==
# pysolorie

[![Quality Checks](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions/workflows/quality_checks.yml)
[![Publish](https://github.com/aaghamohammadi/pysolorie/actions/workflows/publish.yml/badge.svg?branch=main)](https://github.com/aaghamohammadi/pysolorie/actions/workflows/publish.yml)
![GitHub License](https://img.shields.io/github/license/aaghamohammadi/pysolorie)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pysolorie)
[![Documentation Status](https://readthedocs.org/projects/pysolorie/badge/?version=latest)](https://pysolorie.readthedocs.io/en/latest/?badge=latest)
![PyPI - Version](https://img.shields.io/pypi/v/pysolorie)
![PyPI - Format](https://img.shields.io/pypi/format/pysolorie)
![PyPI - Status](https://img.shields.io/pypi/status/pysolorie)
[![codecov](https://codecov.io/gh/aaghamohammadi/pysolorie/graph/badge.svg?token=TF9E8Y3Q67)](https://codecov.io/gh/aaghamohammadi/pysolorie)

**pysolorie** stands for **Py**thon **Sol**ar **Orie**ntation Analysis of Solar Panel. It is a Python library designed to help you analyze the orientation of solar panels.

<img src="docs/_static/images/solar_panel.svg" width="600">

How can one maximize the solar irradiation energy received by a solar panel?


## Features

``pysolorie`` is a library designed to help you find this optimal orientation. Its features include, but are not limited to:

- Finding the optimal orientation for a fixed solar panel under the assumption of a clear-sky model.
- Plotting the Optimal Orientation for a range of days.
- Generating a CSV Report of the optimal orientation for a range of days.
- Calculating the sunrise and sunset hour angles for a given day.
- Utilizing the Hottel's Model to estimate clear-sky beam radiation transmittance.
- Calculating the solar zenith angle.
- Calculating the solar time.
- Calculating Solar Declination and Hour Angle.



## Documentation

You can find the complete documentation for pysolorie at our [Read the Docs page](https://pysolorie.readthedocs.io/).

## Contributing

We welcome contributions to pysolorie! If you're interested in contributing, please take a look at our [contribution guidelines](https://pysolorie.readthedocs.io/en/latest/contributing.html) for detailed information on how you can help.

Thank you for considering contributing to pysolorie!
